import { BaseApiClient } from './base';
import { API_CONFIG } from '../config/api';

// Type definitions based on the API specs
export interface CandidateSearchResult {
  candidatos: Candidate[];
}

export interface Candidate {
  idCandidato: string;
  nome: string;
  cpf: string;
  dataNascimento: string;
  email: string;
  estadoCivil: string;
  sexo: string;
  ocupacao: string;
  fotoUrl: string;
}

export interface CandidateDetails extends Candidate {
  eleicoes: Election[];
}

export interface Election {
  sqCandidato: string;
  tipoEleicao: string;
  cargo: string;
  ano: number;
  siglaUF: string;
  nomeUE: string;
  nrCandidato: string;
  nomeCandidato: string;
  resultado: string;
}

export interface CandidateAssets {
  bens: Asset[];
}

export interface Asset {
  idCandidato: string;
  ano: number;
  tipoBem: string;
  descricao: string;
  valor: number;
}

export interface CandidateRedesSociais {
  redesSociais: RedeSocial[];
}

export interface RedeSocial {
  idCandidato: string;
  rede: "Facebook" | "Instagram" | "X/Twitter" | "TikTok" | "YouTube" | "LinkedIn" | "WhatsApp" | "Threads" | "Telegram" | "Kwai" | "Spotify" | "Outros";
  siglaUF: string;
  link: string;
  ano: number;
}

export interface PlatformStats {
  totalCandidatos: number;
  totalBemCandidatos: number;
  totalValorBemCandidatos: number;
  totalRedesSociais: number;
  totalEleicoes: number;
}

/**
 * OpenCand API client for interacting with the OpenCand platform
 */
export class OpenCandApi extends BaseApiClient {
  constructor(baseUrl: string = '') {
    super(baseUrl);
  }

  /**
   * Get platform statistics
   * GET /v1/stats
   */
  async getStats(): Promise<PlatformStats> {
    return this.get<PlatformStats>('/v1/stats');
  }

  /**
   * Search for candidates by name or other attributes
   * GET /v1/candidato/search?q={query}
   */
  async searchCandidates(query: string): Promise<CandidateSearchResult> {
    const encodedQuery = encodeURIComponent(query);
    return this.get<CandidateSearchResult>(`/v1/candidato/search?q=${encodedQuery}`);
  }

  /**
   * Get detailed information about a specific candidate by ID
   * GET /v1/candidato/{id}
   */
  async getCandidateById(id: string): Promise<CandidateDetails> {
    return this.get<CandidateDetails>(`/v1/candidato/${id}`);
  }

  /**
   * Get the assets of a specific candidate by ID
   * GET /v1/candidato/{id}/bens
   */
  async getCandidateAssets(id: string): Promise<CandidateAssets> {
    return this.get<CandidateAssets>(`/v1/candidato/${id}/bens`);
  }

  /**
   * Get the assets of a specific candidate by ID
   * GET /v1/candidato/{id}/bens
   */
  async getCandidateRedesSociais(id: string): Promise<CandidateRedesSociais> {
    return this.get<CandidateRedesSociais>(`/v1/candidato/${id}/rede-social`);
  }
}

// Create a default instance for easy usage with proper configuration
export const openCandApi = new OpenCandApi(API_CONFIG.baseUrl);

// Export the API error for error handling
export { ApiError } from './base';
