import React, { useState, useEffect } from 'react';
import { useParams, useNavigate } from 'react-router-dom';
import { ArrowLeftIcon, UserIcon, DocumentTextIcon, CurrencyDollarIcon, LinkIcon } from '@heroicons/react/24/outline';
import { openCandApi, type CandidateDetails, type CandidateAssets, type CandidateRedesSociais, type Election, type Asset, type RedeSocial, ApiError } from '../api';

const CandidatePage: React.FC = () => {
  const { id } = useParams<{ id: string }>();
  const navigate = useNavigate();
  const [candidateDetails, setCandidateDetails] = useState<CandidateDetails | null>(null);
  const [candidateAssets, setCandidateAssets] = useState<CandidateAssets | null>(null);
  const [candidateRedesSociais, setCandidateRedesSociais] = useState<CandidateRedesSociais | null>(null);
  const [isLoadingDetails, setIsLoadingDetails] = useState(true);
  const [isLoadingAssets, setIsLoadingAssets] = useState(true);
  const [isLoadingRedesSociais, setIsLoadingRedesSociais] = useState(true);
  const [error, setError] = useState<string | null>(null);

  useEffect(() => {
    if (!id) {
      navigate('/');
      return;
    }

    // Fetch candidate details
    const fetchCandidateDetails = async () => {
      try {
        setIsLoadingDetails(true);
        const details = await openCandApi.getCandidateById(id);
        setCandidateDetails(details);
      } catch (err) {
        console.error('Error fetching candidate details:', err);
        if (err instanceof ApiError) {
          setError(`Erro ao carregar dados do candidato: ${err.message}`);
        } else {
          setError('Erro inesperado ao carregar dados do candidato');
        }
      } finally {
        setIsLoadingDetails(false);
      }
    };

    // Fetch candidate assets
    const fetchCandidateAssets = async () => {
      try {
        setIsLoadingAssets(true);
        const assets = await openCandApi.getCandidateAssets(id);
        setCandidateAssets(assets);
      } catch (err) {
        console.error('Error fetching candidate assets:', err);
        // Assets might not be available for all candidates, so we don't set error here
      } finally {
        setIsLoadingAssets(false);
      }
    };

    // Fetch candidate social media
    const fetchCandidateRedesSociais = async () => {
      try {
        setIsLoadingRedesSociais(true);
        const redesSociais = await openCandApi.getCandidateRedesSociais(id);
        setCandidateRedesSociais(redesSociais);
      } catch (err) {
        console.error('Error fetching candidate social media:', err);
        // Social media might not be available for all candidates, so we don't set error here
      } finally {
        setIsLoadingRedesSociais(false);
      }
    };

    fetchCandidateDetails();
    fetchCandidateAssets();
    fetchCandidateRedesSociais();
  }, [id, navigate]);

  const formatCurrency = (value: number) => {
    return new Intl.NumberFormat('pt-BR', {
      style: 'currency',
      currency: 'BRL'
    }).format(value);
  };

  const formatDate = (dateString: string) => {
    try {
      const date = new Date(dateString);
      return date.toLocaleDateString('pt-BR');
    } catch {
      return dateString;
    }
  };

  if (error) {
    return (
      <main className="flex-grow flex items-center justify-center min-h-screen p-4">
        <div className="text-center text-white">
          <h1 className="text-2xl font-bold mb-4">Erro</h1>
          <p className="text-red-400 mb-4">{error}</p>
          <button
            onClick={() => navigate('/')}
            className="bg-blue-600 hover:bg-blue-700 text-white px-6 py-2 rounded-lg transition-colors"
          >
            Voltar ao Início
          </button>
        </div>
      </main>
    );
  }

  return (
    <main className="flex-grow p-6 max-w-7xl mx-auto">
      {/* Header with back button */}
      <div className="mb-6">
        <button
          onClick={() => navigate('/')}
          className="flex items-center text-white hover:text-gray-300 transition-colors mb-4"
        >
          <ArrowLeftIcon className="h-5 w-5 mr-2" />
          Voltar à busca
        </button>
        
        {candidateDetails && (
          <h1 className="text-3xl font-bold text-white">{candidateDetails.nome}</h1>
        )}
      </div>

      <div className="grid grid-cols-1 lg:grid-cols-3 gap-6 h-full">
        {/* Left Column - Basic Information and Social Media */}
        <div className="lg:col-span-1 space-y-6">
          {/* Basic Information Panel */}
          <div className="bg-white/95 backdrop-blur-sm rounded-xl shadow-lg hover:shadow-xl transform hover:scale-[1.02] transition-all duration-200 p-6">
            <div className="flex items-center mb-6">
              <UserIcon className="h-8 w-8 text-blue-600 mr-3" />
              <h2 className="text-2xl font-bold text-gray-900">Informações Básicas</h2>
            </div>

            {isLoadingDetails ? (
              <div className="flex items-center justify-center h-64">
                <div className="animate-spin rounded-full h-12 w-12 border-4 border-blue-600 border-t-transparent"></div>
              </div>
            ) : candidateDetails ? (
              <div className="space-y-4">
                {/* Candidate Photo */}
                {candidateDetails.fotoUrl && (
                  <div className="flex justify-center mb-6">
                    <div className="relative">
                      <img
                        src={candidateDetails.fotoUrl}
                        alt={`Foto de ${candidateDetails.nome}`}
                        className="w-32 h-32 rounded-full object-cover border-4 border-blue-200 shadow-lg"
                        onError={(e) => {
                          const target = e.target as HTMLImageElement;
                          target.style.display = 'none';
                        }}
                      />
                    </div>
                  </div>
                )}

                <div>
                  <label className="text-sm font-semibold text-gray-600 uppercase tracking-wide">Nome</label>
                  <p className="text-lg font-medium text-gray-900 mt-1">{candidateDetails.nome}</p>
                </div>

                <div>
                  <label className="text-sm font-semibold text-gray-600 uppercase tracking-wide">CPF</label>
                  <p className="text-lg text-gray-900 mt-1">{candidateDetails.cpf}</p>
                </div>

                <div>
                  <label className="text-sm font-semibold text-gray-600 uppercase tracking-wide">Data de Nascimento</label>
                  <p className="text-lg text-gray-900 mt-1">{formatDate(candidateDetails.dataNascimento)}</p>
                </div>

                {candidateDetails.email && (
                  <div>
                    <label className="text-sm font-semibold text-gray-600 uppercase tracking-wide">Email</label>
                    <p className="text-lg text-gray-900 mt-1">{candidateDetails.email}</p>
                  </div>
                )}

                <div>
                  <label className="text-sm font-semibold text-gray-600 uppercase tracking-wide">Estado Civil</label>
                  <p className="text-lg text-gray-900 mt-1">{candidateDetails.estadoCivil}</p>
                </div>

                <div>
                  <label className="text-sm font-semibold text-gray-600 uppercase tracking-wide">Sexo</label>
                  <p className="text-lg text-gray-900 mt-1">{candidateDetails.sexo}</p>
                </div>

                <div>
                  <label className="text-sm font-semibold text-gray-600 uppercase tracking-wide">Ocupação</label>
                  <p className="text-lg text-gray-900 mt-1">{candidateDetails.ocupacao}</p>
                </div>
              </div>
            ) : (
              <div className="text-center text-gray-500 py-8">
                Nenhuma informação encontrada
              </div>
            )}
          </div>

          {/* Social Media Panel */}
          <div className="bg-white/95 backdrop-blur-sm rounded-xl shadow-lg hover:shadow-xl transform hover:scale-[1.02] transition-all duration-200 p-6">
            <div className="flex items-center mb-6">
              <LinkIcon className="h-8 w-8 text-orange-600 mr-3" />
              <h2 className="text-2xl font-bold text-gray-900">Redes Sociais</h2>
            </div>

            {isLoadingRedesSociais ? (
              <div className="flex items-center justify-center h-32">
                <div className="animate-spin rounded-full h-8 w-8 border-4 border-orange-600 border-t-transparent"></div>
              </div>
            ) : candidateRedesSociais?.redesSociais && candidateRedesSociais.redesSociais.length > 0 ? (
              <div className="space-y-3">
                {candidateRedesSociais.redesSociais.map((redeSocial: RedeSocial, index: number) => (
                  <div key={`${redeSocial.idCandidato}-${redeSocial.rede}-${index}`} className="border border-gray-200 rounded-lg p-3 hover:bg-gray-50 transition-colors">
                    <div className="flex items-center justify-between">
                      <div className="flex-1">
                        <div className="flex items-center mb-2">
                          <span className="font-semibold text-gray-900 mr-2">{redeSocial.rede}</span>
                          <span className="text-sm text-gray-500">({redeSocial.ano})</span>
                        </div>
                        <a 
                          href={redeSocial.link} 
                          target="_blank" 
                          rel="noopener noreferrer"
                          className="text-blue-600 hover:text-blue-800 text-sm break-all transition-colors"
                        >
                          {redeSocial.link}
                        </a>
                      </div>
                    </div>
                  </div>
                ))}
              </div>
            ) : (
              <div className="text-center text-gray-500 py-8">
                Nenhuma rede social encontrada
              </div>
            )}
          </div>
        </div>

        {/* Right Column - Elections and Assets */}
        <div className="lg:col-span-2 space-y-6">
          {/* Elections Panel */}
          <div className="bg-white/95 backdrop-blur-sm rounded-xl shadow-lg hover:shadow-xl transform hover:scale-[1.02] transition-all duration-200 p-6">
            <div className="flex items-center mb-6">
              <DocumentTextIcon className="h-8 w-8 text-green-600 mr-3" />
              <h2 className="text-2xl font-bold text-gray-900">Histórico de Eleições</h2>
            </div>

            {isLoadingDetails ? (
              <div className="flex items-center justify-center h-32">
                <div className="animate-spin rounded-full h-8 w-8 border-4 border-green-600 border-t-transparent"></div>
              </div>
            ) : candidateDetails?.eleicoes && candidateDetails.eleicoes.length > 0 ? (
              <div className="overflow-x-auto">
                <table className="w-full table-auto">
                  <thead>
                    <tr className="border-b border-gray-200">
                      <th className="text-left py-3 px-2 font-semibold text-gray-700">Ano</th>
                      <th className="text-left py-3 px-2 font-semibold text-gray-700">Tipo</th>
                      <th className="text-left py-3 px-2 font-semibold text-gray-700">Cargo</th>
                      <th className="text-left py-3 px-2 font-semibold text-gray-700">UF</th>
                      <th className="text-left py-3 px-2 font-semibold text-gray-700">Localidade</th>
                      <th className="text-left py-3 px-2 font-semibold text-gray-700">Número</th>
                      <th className="text-left py-3 px-2 font-semibold text-gray-700">Resultado</th>
                    </tr>
                  </thead>
                  <tbody>
                    {candidateDetails.eleicoes.map((election: Election, index: number) => (
                      <tr key={election.sqCandidato || index} className="border-b border-gray-100 hover:bg-gray-50 transition-colors">
                        <td className="py-3 px-2 text-gray-900">{election.ano}</td>
                        <td className="py-3 px-2 text-gray-900">{election.tipoEleicao}</td>
                        <td className="py-3 px-2 text-gray-900">{election.cargo}</td>
                        <td className="py-3 px-2 text-gray-900">{election.siglaUF}</td>
                        <td className="py-3 px-2 text-gray-900">{election.nomeUE}</td>
                        <td className="py-3 px-2 text-gray-900">{election.nrCandidato}</td>
                        <td className="py-3 px-2">
                          <span className={`px-2 py-1 rounded-full text-xs font-medium ${
                            election.resultado?.toLowerCase().includes('eleito') 
                              ? 'bg-green-100 text-green-800' 
                              : 'bg-gray-100 text-gray-800'
                          }`}>
                            {election.resultado}
                          </span>
                        </td>
                      </tr>
                    ))}
                  </tbody>
                </table>
              </div>
            ) : (
              <div className="text-center text-gray-500 py-8">
                Nenhum histórico de eleições encontrado
              </div>
            )}
          </div>

          {/* Assets Panel */}
          <div className="bg-white/95 backdrop-blur-sm rounded-xl shadow-lg hover:shadow-xl transform hover:scale-[1.02] transition-all duration-200 p-6">
            <div className="flex items-center mb-6">
              <CurrencyDollarIcon className="h-8 w-8 text-purple-600 mr-3" />
              <h2 className="text-2xl font-bold text-gray-900">Patrimônio Declarado</h2>
            </div>

            {isLoadingAssets ? (
              <div className="flex items-center justify-center h-32">
                <div className="animate-spin rounded-full h-8 w-8 border-4 border-purple-600 border-t-transparent"></div>
              </div>
            ) : candidateAssets?.bens && candidateAssets.bens.length > 0 ? (
              <>
                <div className="overflow-x-auto">
                  <table className="w-full table-auto">
                    <thead>
                      <tr className="border-b border-gray-200">
                        <th className="text-left py-3 px-2 font-semibold text-gray-700">Ano</th>
                        <th className="text-left py-3 px-2 font-semibold text-gray-700">Tipo</th>
                        <th className="text-left py-3 px-2 font-semibold text-gray-700">Descrição</th>
                        <th className="text-right py-3 px-2 font-semibold text-gray-700">Valor</th>
                      </tr>
                    </thead>
                    <tbody>
                      {candidateAssets.bens.map((asset: Asset, index: number) => (
                        <tr key={`${asset.idCandidato}-${asset.ano}-${index}`} className="border-b border-gray-100 hover:bg-gray-50 transition-colors">
                          <td className="py-3 px-2 text-gray-900">{asset.ano}</td>
                          <td className="py-3 px-2 text-gray-900">{asset.tipoBem}</td>
                          <td className="py-3 px-2 text-gray-900">{asset.descricao}</td>
                          <td className="py-3 px-2 text-right text-gray-900 font-medium">
                            {formatCurrency(asset.valor)}
                          </td>
                        </tr>
                      ))}
                    </tbody>
                  </table>
                </div>
                
                {/* Total Assets */}
                <div className="mt-4 pt-4 border-t border-gray-200">
                  <div className="flex justify-between items-center">
                    <span className="text-lg font-semibold text-gray-700">Total Declarado:</span>
                    <span className="text-xl font-bold text-purple-600">
                      {formatCurrency(candidateAssets.bens.reduce((total, asset) => total + asset.valor, 0))}
                    </span>
                  </div>
                </div>
              </>
            ) : (
              <div className="text-center text-gray-500 py-8">
                Nenhum patrimônio declarado encontrado
              </div>
            )}
          </div>
        </div>
      </div>
    </main>
  );
};

export default CandidatePage;
